package
Version:
v0.0.0-...-c9ea16c
Opens a new window with list of versions in this module.
Published: Apr 4, 2022
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Item the type of the queue
type ItemQueue struct {
}
ItemQueue the queue of Items
Dequeue remove an Item from the start of the queue
Enqueue add an Item to the end of the queue
IsEmpty return true if the queue is empty
Len return the number of Items in the queue
New create a new ItemQueue
Peek return the item next in the queue, without removing it
Source Files
¶
Click to show internal directories.
Click to hide internal directories.